@@ -19,7 +19,6 @@ describe 'nova::api' do
     context 'with default parameters' do
 
       it { is_expected.to contain_class('nova::keystone::authtoken') }
-      it { is_expected.to contain_class('cinder::client').that_notifies('Nova::Generic_service[api]') }
 
       it 'installs nova-api package and service' do
         is_expected.to contain_service('nova-api').with(
@@ -43,31 +42,31 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/enabled_apis').with_value('osapi_compute,metadata')
       end
 
-      it { is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_ensure('absent')}
 
       it { is_expected.to contain_class('nova::availability_zone') }
 
       it 'configures various stuff' do
-        is_expected.to contain_nova_config('wsgi/api_paste_config').with('value' => 'api-paste.ini')
-        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with('value' => '0.0.0.0')
-        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with('value' => '8774')
-        is_expected.to contain_nova_config('DEFAULT/metadata_listen').with('value' => '0.0.0.0')
-        is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with('value' => '8775')
-        is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with('value' => '5')
-        is_expected.to contain_nova_config('DEFAULT/metadata_workers').with('value' => '5')
+        is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('wsgi/api_paste_config').with_value('api-paste.ini')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with_value('0.0.0.0')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with_value('8774')
+        is_expected.to contain_nova_config('DEFAULT/metadata_listen').with_value('0.0.0.0')
+        is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with_value('8775')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with_value('5')
+        is_expected.to contain_nova_config('DEFAULT/metadata_workers').with_value('5')
         is_expected.to contain_oslo__middleware('nova_config').with(
           :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
           :max_request_body_size        => '<SERVICE DEFAULT>',
         )
-        is_expected.to contain_nova_config('api/max_limit').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/compute_link_prefix').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/glance_link_prefix').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/hide_server_address_states').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/allow_instance_snapshots').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/enable_network_quota').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/enable_instance_password').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/password_length').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with('value' => false)
+        is_expected.to contain_nova_config('api/max_limit').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/compute_link_prefix').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/glance_link_prefix').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/hide_server_address_states').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/allow_instance_snapshots').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/enable_network_quota').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/enable_instance_password').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/password_length').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with_value(false)
       end
     end
 
@@ -81,7 +80,6 @@ describe 'nova::api' do
           :metadata_listen_port         => 8875,
           :osapi_compute_listen_port    => 8874,
           :use_forwarded_for            => false,
-          :ratelimits                   => '(GET, "*", .*, 100, MINUTE);(POST, "*", .*, 200, MINUTE)',
           :osapi_compute_workers        => 1,
           :metadata_workers             => 2,
           :enable_proxy_headers_parsing => true,
@@ -114,26 +112,26 @@ describe 'nova::api' do
       end
 
       it 'configures various stuff' do
-        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with('value' => '192.168.56.210')
-        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with('value' => '8874')
-        is_expected.to contain_nova_config('DEFAULT/metadata_listen').with('value' => '127.0.0.1')
-        is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with('value' => '8875')
-        is_expected.to contain_nova_config('api/use_forwarded_for').with('value' => false)
-        is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with('value' => '1')
-        is_expected.to contain_nova_config('DEFAULT/metadata_workers').with('value' => '2')
-        is_expected.to contain_nova_config('api/max_limit').with('value' => '1000')
-        is_expected.to contain_nova_config('api/compute_link_prefix').with('value' => 'https://10.0.0.1:7777/')
-        is_expected.to contain_nova_config('api/glance_link_prefix').with('value' => 'https://10.0.0.1:6666/')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with_value('192.168.56.210')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with_value('8874')
+        is_expected.to contain_nova_config('DEFAULT/metadata_listen').with_value('127.0.0.1')
+        is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with_value('8875')
+        is_expected.to contain_nova_config('api/use_forwarded_for').with_value(false)
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with_value('1')
+        is_expected.to contain_nova_config('DEFAULT/metadata_workers').with_value('2')
+        is_expected.to contain_nova_config('api/max_limit').with_value('1000')
+        is_expected.to contain_nova_config('api/compute_link_prefix').with_value('https://10.0.0.1:7777/')
+        is_expected.to contain_nova_config('api/glance_link_prefix').with_value('https://10.0.0.1:6666/')
         is_expected.to contain_oslo__middleware('nova_config').with(
           :enable_proxy_headers_parsing => true,
           :max_request_body_size        => '102400',
         )
-        is_expected.to contain_nova_config('api/hide_server_address_states').with('value' => 'building')
-        is_expected.to contain_nova_config('api/allow_instance_snapshots').with('value' => true)
-        is_expected.to contain_nova_config('DEFAULT/enable_network_quota').with('value' => false)
-        is_expected.to contain_nova_config('api/enable_instance_password').with('value' => true)
-        is_expected.to contain_nova_config('DEFAULT/password_length').with('value' => '12')
-        is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with('value' => true)
+        is_expected.to contain_nova_config('api/hide_server_address_states').with_value('building')
+        is_expected.to contain_nova_config('api/allow_instance_snapshots').with_value(true)
+        is_expected.to contain_nova_config('DEFAULT/enable_network_quota').with_value(false)
+        is_expected.to contain_nova_config('api/enable_instance_password').with_value(true)
+        is_expected.to contain_nova_config('DEFAULT/password_length').with_value('12')
+        is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with_value(true)
       end
     end
 
@@ -176,7 +174,7 @@ describe 'nova::api' do
 
     context 'with default database parameters' do
       let :pre_condition do
-        "include nova
+        "include nova::db
          class { 'nova::keystone::authtoken':
            password => 'a_big_secret',
          }"
@@ -191,12 +189,12 @@ describe 'nova::api' do
 
     context 'with overridden database parameters' do
       let :pre_condition do
-        "class { 'nova':
-           database_connection     => 'mysql://user:pass@db/db1',
-           slave_connection        => 'mysql://user:pass@slave/db1',
-           api_database_connection => 'mysql://user:pass@db/db2',
-           api_slave_connection    => 'mysql://user:pass@slave/db2',
-           database_idle_timeout   => '30',
+        "class { 'nova::db':
+           database_connection              => 'mysql://user:pass@db/db1',
+           slave_connection                 => 'mysql://user:pass@slave/db1',
+           api_database_connection          => 'mysql://user:pass@db/db2',
+           api_slave_connection             => 'mysql://user:pass@slave/db2',
+           database_connection_recycle_time => '30',
          }
          class { 'nova::keystone::authtoken':
            password => 'passw0rd',
@@ -301,15 +299,6 @@ describe 'nova::api' do
 
     end
 
-    context 'when disabling cinder client installation' do
-      before do
-        params.merge!({ :install_cinder_client => false })
-      end
-
-      it { is_expected.to_not contain_class('cinder::client') }
-    end
-
-
     context 'when service_name is not valid' do
       before do
         params.merge!({ :service_name   => 'foobar' })
