@@ -24,14 +24,6 @@ describe 'nova::compute' do
         })
       end
 
-      it 'does not configures barbican service' do
-        is_expected.to contain_nova_config('key_manager/backend').with_value('nova.keymgr.conf_key_mgr.ConfKeyManager')
-        is_expected.to contain_nova_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('barbican/barbican_api_version').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>')
-        is_expected.to_not contain_package('cryptsetup').with( :ensure => 'present' )
-      end
-
       it 'does not configure vncproxy base url in nova.conf' do
         is_expected.to contain_nova_config('vnc/enabled').with_value(true)
         is_expected.to_not contain_nova_config('vnc/novncproxy_base_url')
@@ -42,14 +34,21 @@ describe 'nova::compute' do
         is_expected.to contain_nova_config('spice/enabled').with_value(false)
       end
 
+      it { is_expected.to contain_nova_config('DEFAULT/use_cow_images').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/mkisofs_cmd').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/virt_mkfs').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_host_memory_mb').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_host_disk_mb').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/heal_instance_info_cache_interval').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/update_resources_interval').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/reboot_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/instance_build_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/rescue_timeout').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/resize_confirm_window').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/shutdown_timeout').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('glance/verify_glance_signatures').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_builds').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_live_migrations').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/sync_power_state_pool_size').with_value('<SERVICE DEFAULT>') }
@@ -57,6 +56,15 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('compute/live_migration_wait_for_vif_plug').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('compute/max_disk_devices_to_attach').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/default_access_ip_network_name').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/running_deleted_instance_action').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/running_deleted_instance_poll_interval').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/running_deleted_instance_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/compute_monitors').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/default_ephemeral_format').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('compute/image_type_exclude_list').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries_interval').with_value('<SERVICE DEFAULT>') }
 
       it { is_expected.to_not contain_package('bridge-utils').with(
         :ensure => 'present',
@@ -64,13 +72,18 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_class('nova::availability_zone') }
 
-      it 'installs genisoimage package and sets config_drive_format' do
+      it 'installs mkisofs package and sets config_drive_format' do
         is_expected.to contain_nova_config('DEFAULT/config_drive_format').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_package('genisoimage').with(
-          :ensure => 'present',
+        is_expected.to contain_package(platform_params[:mkisofs_package]).with(
+          :ensure => 'installed',
         )
-        is_expected.to contain_package('genisoimage').that_requires('Anchor[nova::install::begin]')
-        is_expected.to contain_package('genisoimage').that_comes_before('Anchor[nova::install::end]')
+        is_expected.to contain_package(platform_params[:mkisofs_package]).that_requires('Anchor[nova::install::begin]')
+        is_expected.to contain_package(platform_params[:mkisofs_package]).that_comes_before('Anchor[nova::install::end]')
+      end
+
+      it 'configures nova pci_passthrough_whitelist' do
+        is_expected.to contain_class('nova::compute::pci')
+        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
       end
     end
 
@@ -79,12 +92,20 @@ describe 'nova::compute' do
         { :enabled                            => false,
           :ensure_package                     => '2012.1-2',
           :vncproxy_host                      => '127.0.0.1',
+          :use_cow_images                     => false,
+          :mkisofs_cmd                        => 'mkisofs',
           :force_raw_images                   => false,
+          :virt_mkfs                          => 'windows=mkfs.ntfs --force --fast %(target)s',
           :reserved_host_memory               => '0',
           :reserved_host_disk                 => '20',
           :heal_instance_info_cache_interval  => '120',
           :config_drive_format                => 'vfat',
+          :update_resources_interval          => '300',
+          :reboot_timeout                     => '180',
+          :instance_build_timeout             => '300',
+          :rescue_timeout                     => '120',
           :resize_confirm_window              => '3',
+          :shutdown_timeout                   => '100',
           :resume_guests_state_on_host_boot   => true,
           :keymgr_backend                     => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
           :barbican_endpoint                  => 'http://localhost',
@@ -94,10 +115,18 @@ describe 'nova::compute' do
           :max_concurrent_live_migrations     => '4',
           :sync_power_state_pool_size         => '10',
           :sync_power_state_interval          => '0',
-          :verify_glance_signatures           => true,
           :consecutive_build_service_disable_threshold => '9',
           :live_migration_wait_for_vif_plug   => true,
           :max_disk_devices_to_attach         => 20,
+          :default_access_ip_network_name     => 'public',
+          :running_deleted_instance_action    => 'shutdown',
+          :running_deleted_instance_poll_interval => '900',
+          :running_deleted_instance_timeout   => '200',
+          :compute_monitors                   => ['cpu.virt_driver','fake'],
+          :default_ephemeral_format           => 'ext4',
+          :image_type_exclude_list            => ['raw','ami'],
+          :block_device_allocate_retries      => 60,
+          :block_device_allocate_retries_interval => 3,
         }
       end
 
@@ -121,7 +150,7 @@ describe 'nova::compute' do
         is_expected.to contain_nova_config('barbican/barbican_endpoint').with_value('http://localhost')
         is_expected.to contain_nova_config('barbican/barbican_api_version').with_value('v1')
         is_expected.to contain_nova_config('barbican/auth_endpoint').with_value('http://127.0.0.1:5000/v3')
-        is_expected.to contain_package('cryptsetup').with( :ensure => 'present' )
+        is_expected.to contain_package('cryptsetup').with_ensure('installed')
       end
 
       it 'configures vnc in nova.conf' do
@@ -136,29 +165,54 @@ describe 'nova::compute' do
         is_expected.to contain_nova_config('spice/enabled').with_value(false)
       end
 
+      it { is_expected.to contain_nova_config('DEFAULT/use_cow_images').with_value(false) }
+      it { is_expected.to contain_nova_config('DEFAULT/mkisofs_cmd').with_value('mkisofs') }
+      it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value(false) }
+      it { is_expected.to contain_nova_config('DEFAULT/virt_mkfs').with_value('windows=mkfs.ntfs --force --fast %(target)s') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_host_memory_mb').with_value('0') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_host_disk_mb').with_value('20') }
       it { is_expected.to contain_nova_config('DEFAULT/heal_instance_info_cache_interval').with_value('120') }
-      it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value(false) }
+      it { is_expected.to contain_nova_config('DEFAULT/update_resources_interval').with_value('300') }
+      it { is_expected.to contain_nova_config('DEFAULT/reboot_timeout').with_value('180') }
+      it { is_expected.to contain_nova_config('DEFAULT/instance_build_timeout').with_value('300') }
+      it { is_expected.to contain_nova_config('DEFAULT/rescue_timeout').with_value('120') }
       it { is_expected.to contain_nova_config('DEFAULT/resize_confirm_window').with_value('3') }
+      it { is_expected.to contain_nova_config('DEFAULT/shutdown_timeout').with_value('100') }
       it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value(true) }
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_builds').with_value('15') }
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_live_migrations').with_value('4') }
       it { is_expected.to contain_nova_config('DEFAULT/sync_power_state_pool_size').with_value('10') }
       it { is_expected.to contain_nova_config('DEFAULT/sync_power_state_interval').with_value('0') }
-      it { is_expected.to contain_nova_config('glance/verify_glance_signatures').with_value(true) }
       it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('9') }
       it { is_expected.to contain_nova_config('compute/live_migration_wait_for_vif_plug').with_value(true) }
       it { is_expected.to contain_nova_config('compute/max_disk_devices_to_attach').with_value(20) }
+      it { is_expected.to contain_nova_config('DEFAULT/default_access_ip_network_name').with_value('public') }
+      it { is_expected.to contain_nova_config('DEFAULT/running_deleted_instance_action').with_value('shutdown') }
+      it { is_expected.to contain_nova_config('DEFAULT/running_deleted_instance_poll_interval').with_value('900') }
+      it { is_expected.to contain_nova_config('DEFAULT/running_deleted_instance_timeout').with_value('200') }
+      it { is_expected.to contain_nova_config('DEFAULT/compute_monitors').with_value('cpu.virt_driver,fake') }
+      it { is_expected.to contain_nova_config('DEFAULT/default_ephemeral_format').with_value('ext4') }
+      it { is_expected.to contain_nova_config('compute/image_type_exclude_list').with_value('raw,ami') }
+      it { is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries').with_value(60) }
+      it { is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries_interval').with_value(3) }
 
       it 'configures nova config_drive_format to vfat' do
         is_expected.to contain_nova_config('DEFAULT/config_drive_format').with_value('vfat')
-        is_expected.to_not contain_package('genisoimage').with(
+        is_expected.to_not contain_package(platform_params[:mkisofs_package]).with(
           :ensure => 'present',
         )
       end
     end
 
+    context 'with image_type_exclude_list set to empty list' do
+      let :params do
+        {
+          :image_type_exclude_list => []
+        }
+      end
+      it { is_expected.to contain_nova_config('compute/image_type_exclude_list').with_value('<SERVICE DEFAULT>') }
+    end
+
     context 'with reserved_huge_pages string' do
       let :params do
         {
@@ -172,6 +226,56 @@ describe 'nova::compute' do
       end
     end
 
+    context 'with pci params array' do
+      let :params do
+        {
+          :pci_passthrough => [
+            {
+              "vendor_id"  => "8086",
+              "product_id" => "0126"
+            },
+            {
+              "vendor_id"        => "9096",
+              "product_id"       => "1520",
+              "physical_network" => "physnet1"
+            }
+          ],
+        }
+      end
+
+      it 'configures nova pci_passthrough_whitelist entries' do
+        is_expected.to contain_class('nova::compute::pci')
+        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(
+          'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
+        )
+      end
+    end
+
+    context 'with pci params JSON encoded string (deprecated)' do
+      let :params do
+        {
+          :pci_passthrough => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]",
+        }
+      end
+
+      it 'configures nova pci_passthrough_whitelist entries' do
+        is_expected.to contain_class('nova::compute::pci')
+        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(
+          'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
+        )
+      end
+    end
+
+    context 'when vcpu_pin_set and pci params are empty' do
+      let :params do
+        { :pci_passthrough => ""}
+      end
+      it 'clears pci_passthrough configuration' do
+        is_expected.to contain_class('nova::compute::pci')
+        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
+      end
+    end
+
     context 'with reserved_huge_pages array' do
       let :params do
         {
@@ -350,16 +454,29 @@ describe 'nova::compute' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts())
       end
-
-      let (:platform_params) do
-        case facts[:osfamily]
-        when 'Debian'
+      case facts[:osfamily]
+      when 'Debian'
+        let (:platform_params) do
           { :nova_compute_package => 'nova-compute',
-            :nova_compute_service => 'nova-compute' }
-        when 'RedHat'
+            :nova_compute_service => 'nova-compute',
+            :mkisofs_package => 'genisoimage' }
+        end
+      when 'RedHat'
+        let (:platform_params) do
           { :nova_compute_package => 'openstack-nova-compute',
             :nova_compute_service => 'openstack-nova-compute' }
         end
+        if facts[:operatingsystemmajrelease] > '8'
+          before do
+            platform_params.merge!({
+              :mkisofs_package => 'xorriso' })
+          end
+        else
+          before do
+            platform_params.merge!({
+              :mkisofs_package => 'genisoimage' })
+          end
+        end
       end
       it_behaves_like 'nova-compute'
     end
