@@ -6,6 +6,9 @@ describe 'nova' do
 
     context 'with default parameters' do
 
+      it { is_expected.to contain_class('nova::deps') }
+      it { is_expected.to contain_class('nova::workarounds') }
+
       it 'installs packages' do
         is_expected.to contain_package('python-nova').with(
           :ensure => 'present',
@@ -27,10 +30,6 @@ describe 'nova' do
         :refreshonly => true
       )}
 
-      it 'does not configure glance api servers' do
-        is_expected.to_not contain_nova_config('glance/api_servers')
-      end
-
       it 'does not configure auth_strategy' do
         is_expected.not_to contain_nova_config('api/auth_strategy')
       end
@@ -50,25 +49,26 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('60')
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
-        is_expected.to contain_nova_config('DEFAULT/ovsdb_connection').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vif_plug_ovs/ovsdb_connection').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/long_rpc_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('cinder/cross_az_attach').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/initial_cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/initial_ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/initial_disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(false)
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('console/ssl_ciphers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('<SERVICE DEFAULT>')
       end
 
-      it 'configures block_device_allocate params' do
-        is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries_interval').with_value('<SERVICE DEFAULT>')
-      end
     end
 
     context 'with overridden parameters' do
@@ -77,9 +77,9 @@ describe 'nova' do
         {
           :glance_endpoint_override                => 'http://localhost:9292',
           :glance_num_retries                      => 3,
-          :glance_api_servers                      => ['http://localhost:9292', 'http://localhost:9293'],
           :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout                    => '30',
+          :long_rpc_timeout                        => '1800',
           :control_exchange                        => 'nova',
           :rabbit_heartbeat_timeout_threshold      => '60',
           :rabbit_heartbeat_rate                   => '10',
@@ -105,17 +105,20 @@ describe 'nova' do
           :upgrade_level_network                   => '1.0.0',
           :upgrade_level_scheduler                 => '1.0.0',
           :purge_config                            => false,
-          :block_device_allocate_retries           => '60',
-          :block_device_allocate_retries_interval  => '3',
           :my_ip                                   => '192.0.2.1',
           :ssl_only                                => true,
           :cert                                    => '/etc/ssl/private/snakeoil.pem',
           :key                                     => '/etc/ssl/certs/snakeoil.pem',
           :console_ssl_ciphers                     => 'kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES',
           :console_ssl_minimum_version             => 'tlsv1_2',
+          :dhcp_domain                             => 'foo',
+
         }
       end
 
+      it { is_expected.to contain_class('nova::deps') }
+      it { is_expected.to contain_class('nova::workarounds') }
+
       it 'installs packages' do
         is_expected.to contain_package('nova-common').with('ensure' => '2012.1.1-15.el6')
         is_expected.to contain_package('python-nova').with('ensure' => '2012.1.1-15.el6')
@@ -130,7 +133,6 @@ describe 'nova' do
       it 'configures glance parameters' do
         is_expected.to contain_nova_config('glance/endpoint_override').with_value('http://localhost:9292')
         is_expected.to contain_nova_config('glance/num_retries').with_value(3)
-        is_expected.to contain_nova_config('glance/api_servers').with_value(['http://localhost:9292', 'http://localhost:9293'])
       end
 
       it 'configures auth_strategy' do
@@ -140,6 +142,7 @@ describe 'nova' do
       it 'configures rabbit' do
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
         is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('30')
+        is_expected.to contain_nova_config('DEFAULT/long_rpc_timeout').with_value('1800')
         is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('nova')
         is_expected.to contain_nova_config('cinder/cross_az_attach').with_value(true)
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
@@ -175,12 +178,13 @@ describe 'nova' do
         is_expected.to contain_nova_config('oslo_messaging_notifications/topics').with_value('openstack')
         is_expected.to contain_nova_config('notifications/notification_format').with_value('unversioned')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
-        is_expected.to contain_nova_config('DEFAULT/ovsdb_connection').with_value('tcp:127.0.0.1:6640')
+        is_expected.to contain_nova_config('vif_plug_ovs/ovsdb_connection').with_value('tcp:127.0.0.1:6640')
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('/etc/ssl/private/snakeoil.pem')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('/etc/ssl/certs/snakeoil.pem')
         is_expected.to contain_nova_config('console/ssl_ciphers').with_value('kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES')
         is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('tlsv1_2')
+        is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('foo')
       end
 
       context 'with multiple notification_driver' do
@@ -190,11 +194,6 @@ describe 'nova' do
           ['ceilometer.compute.nova_notifier', 'nova.openstack.common.notifier.rpc_notifier']
         ) }
       end
-
-      it 'configures block_device_allocate params' do
-        is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries').with_value('60')
-        is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries_interval').with_value('3')
-      end
     end
 
     context 'with wrong notify_on_state_change parameter' do
@@ -301,7 +300,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>')
@@ -501,15 +499,21 @@ describe 'nova' do
     context 'with allocation ratios set' do
       let :params do
         {
-          :cpu_allocation_ratio  => 32.0,
-          :ram_allocation_ratio  => 2.0,
-          :disk_allocation_ratio => 1.5,
+          :cpu_allocation_ratio          => 32.0,
+          :ram_allocation_ratio          => 2.0,
+          :disk_allocation_ratio         => 1.5,
+          :initial_cpu_allocation_ratio  => 64.0,
+          :initial_ram_allocation_ratio  => 4.0,
+          :initial_disk_allocation_ratio => 3.0,
         }
       end
 
-      it { is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value('32.0') }
-      it { is_expected.to contain_nova_config('DEFAULT/ram_allocation_ratio').with_value('2.0') }
-      it { is_expected.to contain_nova_config('DEFAULT/disk_allocation_ratio').with_value('1.5') }
+      it { is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value(32.0) }
+      it { is_expected.to contain_nova_config('DEFAULT/ram_allocation_ratio').with_value(2.0) }
+      it { is_expected.to contain_nova_config('DEFAULT/disk_allocation_ratio').with_value(1.5) }
+      it { is_expected.to contain_nova_config('DEFAULT/initial_cpu_allocation_ratio').with_value(64.0) }
+      it { is_expected.to contain_nova_config('DEFAULT/initial_ram_allocation_ratio').with_value(4.0) }
+      it { is_expected.to contain_nova_config('DEFAULT/initial_disk_allocation_ratio').with_value(3.0) }
     end
 
   end
