@@ -7,23 +7,16 @@ describe 'nova::quota' do
 
   let :default_params do
     {
-      :instances                   => 10,
-      :cores                       => 20,
-      :ram                         => 51200,
-      :floating_ips                => 10,
-      :fixed_ips                   => -1,
-      :metadata_items              => 128,
-      :injected_files              => 5,
-      :injected_file_content_bytes => 10240,
-      :injected_file_path_length   => 255,
-      :security_groups             => 10,
-      :security_group_rules        => 20,
-      :key_pairs                   => 100,
-      :server_groups               => 10,
-      :server_group_members        => 10,
-      :reservation_expire          => 86400,
-      :until_refresh               => 0,
-      :max_age                     => 0
+      :instances                   => '<SERVICE DEFAULT>',
+      :cores                       => '<SERVICE DEFAULT>',
+      :ram                         => '<SERVICE DEFAULT>',
+      :metadata_items              => '<SERVICE DEFAULT>',
+      :injected_files              => '<SERVICE DEFAULT>',
+      :injected_file_content_bytes => '<SERVICE DEFAULT>',
+      :injected_file_path_length   => '<SERVICE DEFAULT>',
+      :key_pairs                   => '<SERVICE DEFAULT>',
+      :server_groups               => '<SERVICE DEFAULT>',
+      :server_group_members        => '<SERVICE DEFAULT>',
     }
   end
 
@@ -50,20 +43,13 @@ describe 'nova::quota' do
           :instances                   => 20,
           :cores                       => 40,
           :ram                         => 102400,
-          :floating_ips                => 20,
-          :fixed_ips                   => 512,
           :metadata_items              => 256,
           :injected_files              => 10,
           :injected_file_content_bytes => 20480,
           :injected_file_path_length   => 254,
-          :security_groups             => 20,
-          :security_group_rules        => 40,
           :key_pairs                   => 200,
           :server_groups               => 20,
           :server_group_members        => 20,
-          :reservation_expire          => 6400,
-          :until_refresh               => 30,
-          :max_age                     => 60
         })
       end
 
