@@ -19,8 +19,7 @@ describe 'nova::scheduler' do
 
     it { is_expected.to contain_nova_config('scheduler/workers').with_value(4) }
     it { is_expected.to contain_nova_config('scheduler/max_attempts').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_nova_config('scheduler/periodic_task_interval').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_nova_config('scheduler/driver').with_ensure('absent') }
+    it { is_expected.to contain_nova_config('scheduler/periodic_task_interval').with_ensure('absent') }
     it { is_expected.to contain_nova_config('scheduler/discover_hosts_in_cells_interval').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_nova_config('scheduler/query_placement_for_image_type_support').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_nova_config('scheduler/limit_tenants_to_placement_aggregate').with_value('<SERVICE DEFAULT>') }
@@ -28,6 +27,7 @@ describe 'nova::scheduler' do
     it { is_expected.to contain_nova_config('scheduler/max_placement_results').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_nova_config('scheduler/enable_isolated_aggregate_filtering').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_nova_config('scheduler/query_placement_for_availability_zone').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_nova_config('scheduler/query_placement_for_routed_network_aggregates').with_value('<SERVICE DEFAULT>') }
 
     it { is_expected.to contain_class('nova::availability_zone') }
 
@@ -66,22 +66,6 @@ describe 'nova::scheduler' do
       it { is_expected.to contain_nova_config('scheduler/max_attempts').with_value(10) }
     end
 
-    context 'with periodic_task_interval' do
-      let :params do
-        { :periodic_task_interval => 300 }
-      end
-
-      it { is_expected.to contain_nova_config('scheduler/periodic_task_interval').with_value(300) }
-    end
-
-    context 'with scheduler driver' do
-      let :params do
-        { :scheduler_driver => 'custom driver' }
-      end
-
-      it { is_expected.to contain_nova_config('scheduler/driver').with_value('custom driver') }
-    end
-
     context 'with discover_hosts_in_cells_interval' do
       let :params do
         { :discover_hosts_in_cells_interval => 15 }
@@ -138,9 +122,17 @@ describe 'nova::scheduler' do
       it { is_expected.to contain_nova_config('scheduler/query_placement_for_availability_zone').with_value(true) }
     end
 
+    context 'with query_placement_for_routed_network_aggregates' do
+      let :params do
+        { :query_placement_for_routed_network_aggregates => true }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/query_placement_for_routed_network_aggregates').with_value(true) }
+    end
+
     context 'with default database parameters' do
       let :pre_condition do
-        "include nova"
+        "include nova::db"
       end
 
       it { is_expected.to_not contain_nova_config('database/connection') }
@@ -150,10 +142,10 @@ describe 'nova::scheduler' do
 
     context 'with overridden database parameters' do
       let :pre_condition do
-        "class { 'nova':
-           database_connection   => 'mysql://user:pass@db/db',
-           slave_connection      => 'mysql://user:pass@slave/db',
-           database_idle_timeout => '30',
+        "class { 'nova::db':
+           database_connection              => 'mysql://user:pass@db/db',
+           slave_connection                 => 'mysql://user:pass@slave/db',
+           database_connection_recycle_time => '30',
          }
         "
       end
