@@ -97,13 +97,13 @@ describe 'nova::wsgi::apache_api' do
       )}
     end
 
-    context 'when ::nova::api is missing in the composition layer' do
+    context 'when nova::api is missing in the composition layer' do
 
       let :pre_condition do
         "include nova"
       end
 
-      it { should raise_error(Puppet::Error, /::nova::api class must be declared in composition layer./) }
+      it { should raise_error(Puppet::Error, /nova::api class must be declared in composition layer./) }
     end
 
   end
@@ -125,14 +125,12 @@ describe 'nova::wsgi::apache_api' do
         when 'Debian'
           {
             :httpd_service_name     => 'apache2',
-            :httpd_ports_file       => '/etc/apache2/ports.conf',
             :wsgi_script_path       => '/usr/lib/cgi-bin/nova',
             :api_wsgi_script_source => '/usr/bin/nova-api-wsgi',
           }
         when 'RedHat'
           {
             :httpd_service_name     => 'httpd',
-            :httpd_ports_file       => '/etc/httpd/conf/ports.conf',
             :wsgi_script_path       => '/var/www/cgi-bin/nova',
             :api_wsgi_script_source => '/usr/bin/nova-api-wsgi',
           }
